"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .canvasrequesttype import CanvasRequestType
from .controlnet_input import (
    ControlnetInput,
    ControlnetInputTypedDict,
    InitImageType,
    StrengthType,
)
from .controlnet_type import ControlnetType
from .custom_model_type import CustomModelType
from .element_input import ElementInput, ElementInputTypedDict
from .job_status import JobStatus
from .lcm_generation_style import LcmGenerationStyle
from .model_asset_texture_types import ModelAssetTextureTypes
from .pricingcalculatorservices import PricingCalculatorServices
from .sd_generation_schedulers import SdGenerationSchedulers
from .sd_generation_style import SdGenerationStyle
from .sd_versions import SdVersions
from .security import Security, SecurityTypedDict
from .strength import Strength
from .universal_upscaler_style import UniversalUpscalerStyle
from .universal_upscaler_ultra_style import UniversalUpscalerUltraStyle
from .user_elements_input import UserElementsInput, UserElementsInputTypedDict
from .variation_type import VariationType

__all__ = [
    "CanvasRequestType",
    "ControlnetInput",
    "ControlnetInputTypedDict",
    "ControlnetType",
    "CustomModelType",
    "ElementInput",
    "ElementInputTypedDict",
    "InitImageType",
    "JobStatus",
    "LcmGenerationStyle",
    "ModelAssetTextureTypes",
    "PricingCalculatorServices",
    "SdGenerationSchedulers",
    "SdGenerationStyle",
    "SdVersions",
    "Security",
    "SecurityTypedDict",
    "Strength",
    "StrengthType",
    "UniversalUpscalerStyle",
    "UniversalUpscalerUltraStyle",
    "UserElementsInput",
    "UserElementsInputTypedDict",
    "VariationType",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.models.shared import (
    universal_upscaler_style as shared_universal_upscaler_style,
    universal_upscaler_ultra_style as shared_universal_upscaler_ultra_style,
)
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateUniversalUpscalerJobRequestBodyTypedDict(TypedDict):
    r"""Query parameters are provided in the request body as a JSON object"""

    creativity_strength: NotRequired[Nullable[int]]
    r"""The creativity strength of the universal upscaler. Must be between 1 and 10."""
    detail_contrast: NotRequired[Nullable[int]]
    r"""The detail contrast of the universal upscaler. Must be between 1 and 10. Can only be used with ultraUpscaleStyle."""
    generated_image_id: NotRequired[Nullable[str]]
    r"""The ID of the generated image."""
    init_image_id: NotRequired[Nullable[str]]
    r"""The ID of the init image uploaded."""
    prompt: NotRequired[Nullable[str]]
    r"""The prompt for the universal upscaler."""
    similarity: NotRequired[Nullable[int]]
    r"""The similarity of the universal upscaler. Must be between 1 and 10. Can only be used with ultraUpscaleStyle."""
    ultra_upscale_style: NotRequired[
        Nullable[shared_universal_upscaler_ultra_style.UniversalUpscalerUltraStyle]
    ]
    r"""The ultra style to upscale images using universal upscaler with. Can not be used with upscalerStyle."""
    upscale_multiplier: NotRequired[Nullable[float]]
    r"""The upscale multiplier of the universal upscaler. Must be between 1.0 and 2.0."""
    upscaler_style: NotRequired[
        Nullable[shared_universal_upscaler_style.UniversalUpscalerStyle]
    ]
    r"""The style to upscale images using universal upscaler with. Can not be used with ultraUpscaleStyle."""
    variation_id: NotRequired[Nullable[str]]
    r"""The ID of the variation image."""


class CreateUniversalUpscalerJobRequestBody(BaseModel):
    r"""Query parameters are provided in the request body as a JSON object"""

    creativity_strength: Annotated[
        OptionalNullable[int], pydantic.Field(alias="creativityStrength")
    ] = 5
    r"""The creativity strength of the universal upscaler. Must be between 1 and 10."""

    detail_contrast: Annotated[
        OptionalNullable[int], pydantic.Field(alias="detailContrast")
    ] = UNSET
    r"""The detail contrast of the universal upscaler. Must be between 1 and 10. Can only be used with ultraUpscaleStyle."""

    generated_image_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="generatedImageId")
    ] = UNSET
    r"""The ID of the generated image."""

    init_image_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="initImageId")
    ] = UNSET
    r"""The ID of the init image uploaded."""

    prompt: OptionalNullable[str] = UNSET
    r"""The prompt for the universal upscaler."""

    similarity: OptionalNullable[int] = UNSET
    r"""The similarity of the universal upscaler. Must be between 1 and 10. Can only be used with ultraUpscaleStyle."""

    ultra_upscale_style: Annotated[
        OptionalNullable[
            shared_universal_upscaler_ultra_style.UniversalUpscalerUltraStyle
        ],
        pydantic.Field(alias="ultraUpscaleStyle"),
    ] = UNSET
    r"""The ultra style to upscale images using universal upscaler with. Can not be used with upscalerStyle."""

    upscale_multiplier: Annotated[
        OptionalNullable[float], pydantic.Field(alias="upscaleMultiplier")
    ] = 1.5
    r"""The upscale multiplier of the universal upscaler. Must be between 1.0 and 2.0."""

    upscaler_style: Annotated[
        OptionalNullable[shared_universal_upscaler_style.UniversalUpscalerStyle],
        pydantic.Field(alias="upscalerStyle"),
    ] = shared_universal_upscaler_style.UniversalUpscalerStyle.GENERAL
    r"""The style to upscale images using universal upscaler with. Can not be used with ultraUpscaleStyle."""

    variation_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="variationId")
    ] = UNSET
    r"""The ID of the variation image."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "creativityStrength",
            "detailContrast",
            "generatedImageId",
            "initImageId",
            "prompt",
            "similarity",
            "ultraUpscaleStyle",
            "upscaleMultiplier",
            "upscalerStyle",
            "variationId",
        ]
        nullable_fields = [
            "creativityStrength",
            "detailContrast",
            "generatedImageId",
            "initImageId",
            "prompt",
            "similarity",
            "ultraUpscaleStyle",
            "upscaleMultiplier",
            "upscalerStyle",
            "variationId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UniversalUpscalerOutputTypedDict(TypedDict):
    api_credit_cost: NotRequired[Nullable[int]]
    r"""API Credits Cost for Universal Upscaler Variation. Available for Production API Users."""
    id: NotRequired[Nullable[str]]


class UniversalUpscalerOutput(BaseModel):
    api_credit_cost: Annotated[
        OptionalNullable[int], pydantic.Field(alias="apiCreditCost")
    ] = UNSET
    r"""API Credits Cost for Universal Upscaler Variation. Available for Production API Users."""

    id: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["apiCreditCost", "id"]
        nullable_fields = ["apiCreditCost", "id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateUniversalUpscalerJobResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /variations/universal-upscaler"""

    universal_upscaler: NotRequired[UniversalUpscalerOutputTypedDict]


class CreateUniversalUpscalerJobResponseBody(BaseModel):
    r"""Responses for POST /variations/universal-upscaler"""

    universal_upscaler: Annotated[
        Optional[UniversalUpscalerOutput], pydantic.Field(alias="universalUpscaler")
    ] = None


class CreateUniversalUpscalerJobResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[CreateUniversalUpscalerJobResponseBodyTypedDict]
    r"""Responses for POST /variations/universal-upscaler"""


class CreateUniversalUpscalerJobResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[CreateUniversalUpscalerJobResponseBody] = None
    r"""Responses for POST /variations/universal-upscaler"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PromptImproveRequestBodyTypedDict(TypedDict):
    r"""Query parameters to be provided in the request body as a JSON object"""

    prompt: str
    r"""The prompt to improve."""
    prompt_instructions: NotRequired[Nullable[str]]
    r"""The prompt is improved based on the given instructions."""


class PromptImproveRequestBody(BaseModel):
    r"""Query parameters to be provided in the request body as a JSON object"""

    prompt: str
    r"""The prompt to improve."""

    prompt_instructions: Annotated[
        OptionalNullable[str], pydantic.Field(alias="promptInstructions")
    ] = UNSET
    r"""The prompt is improved based on the given instructions."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["promptInstructions"]
        nullable_fields = ["promptInstructions"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PromptGenerationOutputTypedDict(TypedDict):
    api_credit_cost: NotRequired[int]
    r"""API Credits Cost for Random Prompt Generation. Available for Production API Users."""
    prompt: NotRequired[str]
    r"""The improved prompt."""


class PromptGenerationOutput(BaseModel):
    api_credit_cost: Annotated[Optional[int], pydantic.Field(alias="apiCreditCost")] = 4
    r"""API Credits Cost for Random Prompt Generation. Available for Production API Users."""

    prompt: Optional[str] = "The improved prompt."
    r"""The improved prompt."""


class PromptImproveResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /prompt/improve"""

    prompt_generation: NotRequired[PromptGenerationOutputTypedDict]


class PromptImproveResponseBody(BaseModel):
    r"""Responses for POST /prompt/improve"""

    prompt_generation: Annotated[
        Optional[PromptGenerationOutput], pydantic.Field(alias="promptGeneration")
    ] = None


class PromptImproveResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[PromptImproveResponseBodyTypedDict]
    r"""Responses for POST /prompt/improve"""


class PromptImproveResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[PromptImproveResponseBody] = None
    r"""Responses for POST /prompt/improve"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SdVersions(str, Enum):
    r"""The base version of stable diffusion to use if not using a custom model."""

    SDXL_0_9 = "SDXL_0_9"
    SDXL_1_0 = "SDXL_1_0"
    LEONARDO_DIFFUSION_XL = "LEONARDO_DIFFUSION_XL"
    LEONARDO_LIGHTNING_XL = "LEONARDO_LIGHTNING_XL"
    VISION_XL = "VISION_XL"
    KINO_XL = "KINO_XL"
    ALBEDO_XL = "ALBEDO_XL"


class CreateElementRequestBodyTypedDict(TypedDict):
    r"""Query parameters to be provided in the request body as a JSON object."""

    dataset_id: NotRequired[str]
    r"""The ID of the dataset to train the element on."""
    description: NotRequired[Nullable[str]]
    r"""The description of the element."""
    instance_prompt: NotRequired[str]
    r"""The instance prompt to use during training.Try “a” by a noun. E.g. a castle"""
    learning_rate: NotRequired[float]
    r"""The speed of element learns."""
    lora_focus: NotRequired[str]
    r"""The category determines how the element will be trained. Options are 'General' | 'Character' | 'Style' | 'Object'."""
    name: NotRequired[str]
    r"""The name of the element."""
    num_train_epochs: NotRequired[int]
    r"""The number of times the entire training dataset is passed through the element."""
    resolution: NotRequired[Nullable[int]]
    r"""The resolution for training. Must be 1024."""
    sd_version: NotRequired[SdVersions]
    r"""The base version of stable diffusion to use if not using a custom model."""
    train_text_encoder: NotRequired[bool]
    r"""Whether or not encode the train text."""


class CreateElementRequestBody(BaseModel):
    r"""Query parameters to be provided in the request body as a JSON object."""

    dataset_id: Annotated[Optional[str], pydantic.Field(alias="datasetId")] = ""
    r"""The ID of the dataset to train the element on."""

    description: OptionalNullable[str] = ""
    r"""The description of the element."""

    instance_prompt: Optional[str] = "a character"
    r"""The instance prompt to use during training.Try “a” by a noun. E.g. a castle"""

    learning_rate: Optional[float] = 0.000001
    r"""The speed of element learns."""

    lora_focus: Optional[str] = "General"
    r"""The category determines how the element will be trained. Options are 'General' | 'Character' | 'Style' | 'Object'."""

    name: Optional[str] = "placeholder"
    r"""The name of the element."""

    num_train_epochs: Optional[int] = 100
    r"""The number of times the entire training dataset is passed through the element."""

    resolution: OptionalNullable[int] = 1024
    r"""The resolution for training. Must be 1024."""

    sd_version: Optional[SdVersions] = SdVersions.SDXL_0_9
    r"""The base version of stable diffusion to use if not using a custom model."""

    train_text_encoder: Optional[bool] = True
    r"""Whether or not encode the train text."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "datasetId",
            "description",
            "instance_prompt",
            "learning_rate",
            "lora_focus",
            "name",
            "num_train_epochs",
            "resolution",
            "sd_version",
            "train_text_encoder",
        ]
        nullable_fields = ["description", "resolution"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class SDTrainingOutputTypedDict(TypedDict):
    api_credit_cost: NotRequired[Nullable[int]]
    r"""API Credits Cost for Model Training. Available for Production API Users."""
    user_lora_id: NotRequired[int]


class SDTrainingOutput(BaseModel):
    api_credit_cost: Annotated[
        OptionalNullable[int], pydantic.Field(alias="apiCreditCost")
    ] = UNSET
    r"""API Credits Cost for Model Training. Available for Production API Users."""

    user_lora_id: Annotated[Optional[int], pydantic.Field(alias="userLoraId")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["apiCreditCost", "userLoraId"]
        nullable_fields = ["apiCreditCost"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateElementResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /elements."""

    sd_training_job: NotRequired[Nullable[SDTrainingOutputTypedDict]]


class CreateElementResponseBody(BaseModel):
    r"""Responses for POST /elements."""

    sd_training_job: Annotated[
        OptionalNullable[SDTrainingOutput], pydantic.Field(alias="sdTrainingJob")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["sdTrainingJob"]
        nullable_fields = ["sdTrainingJob"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateElementResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[CreateElementResponseBodyTypedDict]
    r"""Responses for POST /elements."""


class CreateElementResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[CreateElementResponseBody] = None
    r"""Responses for POST /elements."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SdGenerationSchedulers(str, Enum):
    r"""The scheduler to generate images with. Defaults to EULER_DISCRETE if not specified."""

    KLMS = "KLMS"
    EULER_ANCESTRAL_DISCRETE = "EULER_ANCESTRAL_DISCRETE"
    EULER_DISCRETE = "EULER_DISCRETE"
    DDIM = "DDIM"
    DPM_SOLVER = "DPM_SOLVER"
    PNDM = "PNDM"
    LEONARDO = "LEONARDO"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PricingCalculatorServices(str, Enum):
    r"""The services to be chosen for calculating the API credit cost."""

    IMAGE_GENERATION = "IMAGE_GENERATION"
    FANTASY_AVATAR_GENERATION = "FANTASY_AVATAR_GENERATION"
    MOTION_GENERATION = "MOTION_GENERATION"
    LCM_GENERATION = "LCM_GENERATION"
    MODEL_TRAINING = "MODEL_TRAINING"
    TEXTURE_GENERATION = "TEXTURE_GENERATION"
    UNIVERSAL_UPSCALER = "UNIVERSAL_UPSCALER"
    UNIVERSAL_UPSCALER_ULTRA = "UNIVERSAL_UPSCALER_ULTRA"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class Strength(str, Enum):
    r"""When training using the PIXEL_ART model type, this influences the training strength."""

    VERY_LOW = "VERY_LOW"
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.models.shared import (
    custom_model_type as shared_custom_model_type,
    job_status as shared_job_status,
    sd_versions as shared_sd_versions,
)
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from leonardo_ai_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetCustomModelsByUserIDRequestTypedDict(TypedDict):
    user_id: str
    r"""The ID of the user to return."""


class GetCustomModelsByUserIDRequest(BaseModel):
    user_id: Annotated[
        str,
        pydantic.Field(alias="userId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The ID of the user to return."""


class GetCustomModelsByUserIDCustomModelsTypedDict(TypedDict):
    r"""columns and relationships of \"custom_models\" """

    created_at: NotRequired[str]
    description: NotRequired[str]
    id: NotRequired[Nullable[str]]
    instance_prompt: NotRequired[Nullable[str]]
    model_height: NotRequired[int]
    model_width: NotRequired[int]
    name: NotRequired[str]
    public: NotRequired[bool]
    sd_version: NotRequired[shared_sd_versions.SdVersions]
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""
    status: NotRequired[shared_job_status.JobStatus]
    r"""The status of the current task."""
    type: NotRequired[shared_custom_model_type.CustomModelType]
    r"""The category the most accurately reflects the model."""
    updated_at: NotRequired[str]


class GetCustomModelsByUserIDCustomModels(BaseModel):
    r"""columns and relationships of \"custom_models\" """

    created_at: Annotated[Optional[str], pydantic.Field(alias="createdAt")] = None

    description: Optional[str] = None

    id: OptionalNullable[str] = UNSET

    instance_prompt: Annotated[
        OptionalNullable[str], pydantic.Field(alias="instancePrompt")
    ] = UNSET

    model_height: Annotated[Optional[int], pydantic.Field(alias="modelHeight")] = None

    model_width: Annotated[Optional[int], pydantic.Field(alias="modelWidth")] = None

    name: Optional[str] = None

    public: Optional[bool] = None

    sd_version: Annotated[
        Optional[shared_sd_versions.SdVersions], pydantic.Field(alias="sdVersion")
    ] = None
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""

    status: Optional[shared_job_status.JobStatus] = None
    r"""The status of the current task."""

    type: Optional[shared_custom_model_type.CustomModelType] = (
        shared_custom_model_type.CustomModelType.GENERAL
    )
    r"""The category the most accurately reflects the model."""

    updated_at: Annotated[Optional[str], pydantic.Field(alias="updatedAt")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "createdAt",
            "description",
            "id",
            "instancePrompt",
            "modelHeight",
            "modelWidth",
            "name",
            "public",
            "sdVersion",
            "status",
            "type",
            "updatedAt",
        ]
        nullable_fields = ["id", "instancePrompt"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetCustomModelsByUserIDResponseBodyTypedDict(TypedDict):
    r"""Responses for GET /models/user/{userId}"""

    custom_models: NotRequired[
        Nullable[List[GetCustomModelsByUserIDCustomModelsTypedDict]]
    ]


class GetCustomModelsByUserIDResponseBody(BaseModel):
    r"""Responses for GET /models/user/{userId}"""

    custom_models: OptionalNullable[List[GetCustomModelsByUserIDCustomModels]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["custom_models"]
        nullable_fields = ["custom_models"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetCustomModelsByUserIDResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[GetCustomModelsByUserIDResponseBodyTypedDict]
    r"""Responses for GET /models/user/{userId}"""


class GetCustomModelsByUserIDResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[GetCustomModelsByUserIDResponseBody] = None
    r"""Responses for GET /models/user/{userId}"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.models.shared import (
    job_status as shared_job_status,
    sd_generation_schedulers as shared_sd_generation_schedulers,
    sd_generation_style as shared_sd_generation_style,
    sd_versions as shared_sd_versions,
    variation_type as shared_variation_type,
)
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from leonardo_ai_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetGenerationByIDRequestTypedDict(TypedDict):
    id: str
    r"""The ID of the generation to return."""


class GetGenerationByIDRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the generation to return."""


class GetGenerationByIDGeneratedImageVariationGenericTypedDict(TypedDict):
    r"""columns and relationships of \"generated_image_variation_generic\" """

    id: NotRequired[Nullable[str]]
    status: NotRequired[shared_job_status.JobStatus]
    r"""The status of the current task."""
    transform_type: NotRequired[shared_variation_type.VariationType]
    r"""The type of variation."""
    url: NotRequired[Nullable[str]]


class GetGenerationByIDGeneratedImageVariationGeneric(BaseModel):
    r"""columns and relationships of \"generated_image_variation_generic\" """

    id: OptionalNullable[str] = UNSET

    status: Optional[shared_job_status.JobStatus] = None
    r"""The status of the current task."""

    transform_type: Annotated[
        Optional[shared_variation_type.VariationType],
        pydantic.Field(alias="transformType"),
    ] = None
    r"""The type of variation."""

    url: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "status", "transformType", "url"]
        nullable_fields = ["id", "url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GeneratedImagesTypedDict(TypedDict):
    r"""columns and relationships of \"generated_images\" """

    fantasy_avatar: NotRequired[Nullable[bool]]
    r"""If fantasyAvatar feature was used."""
    generated_image_variation_generics: NotRequired[
        List[GetGenerationByIDGeneratedImageVariationGenericTypedDict]
    ]
    id: NotRequired[Nullable[str]]
    image_to_video: NotRequired[Nullable[bool]]
    r"""If it is an image to video generation."""
    like_count: NotRequired[int]
    motion: NotRequired[Nullable[bool]]
    r"""If generation is of motion type."""
    motion_mp4_url: NotRequired[Nullable[str]]
    r"""The URL of the motion MP4."""
    motion_model: NotRequired[Nullable[str]]
    r"""The name of the motion model."""
    motion_strength: NotRequired[Nullable[int]]
    r"""The motion strength."""
    nsfw: NotRequired[bool]
    url: NotRequired[str]


class GeneratedImages(BaseModel):
    r"""columns and relationships of \"generated_images\" """

    fantasy_avatar: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="fantasyAvatar")
    ] = UNSET
    r"""If fantasyAvatar feature was used."""

    generated_image_variation_generics: Optional[
        List[GetGenerationByIDGeneratedImageVariationGeneric]
    ] = None

    id: OptionalNullable[str] = UNSET

    image_to_video: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="imageToVideo")
    ] = UNSET
    r"""If it is an image to video generation."""

    like_count: Annotated[Optional[int], pydantic.Field(alias="likeCount")] = None

    motion: OptionalNullable[bool] = UNSET
    r"""If generation is of motion type."""

    motion_mp4_url: Annotated[
        OptionalNullable[str], pydantic.Field(alias="motionMP4URL")
    ] = UNSET
    r"""The URL of the motion MP4."""

    motion_model: Annotated[
        OptionalNullable[str], pydantic.Field(alias="motionModel")
    ] = UNSET
    r"""The name of the motion model."""

    motion_strength: Annotated[
        OptionalNullable[int], pydantic.Field(alias="motionStrength")
    ] = UNSET
    r"""The motion strength."""

    nsfw: Optional[bool] = None

    url: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "fantasyAvatar",
            "generated_image_variation_generics",
            "id",
            "imageToVideo",
            "likeCount",
            "motion",
            "motionMP4URL",
            "motionModel",
            "motionStrength",
            "nsfw",
            "url",
        ]
        nullable_fields = [
            "fantasyAvatar",
            "id",
            "imageToVideo",
            "motion",
            "motionMP4URL",
            "motionModel",
            "motionStrength",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetGenerationByIDLorasTypedDict(TypedDict):
    r"""Element used for the generation."""

    ak_uuid: NotRequired[Nullable[str]]
    r"""Unique identifier for the element. Elements can be found from the List Elements endpoint."""
    base_model: NotRequired[shared_sd_versions.SdVersions]
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""
    description: NotRequired[Nullable[str]]
    r"""Description for the element"""
    name: NotRequired[Nullable[str]]
    r"""Name of the element"""
    url_image: NotRequired[Nullable[str]]
    r"""URL of the element image"""
    weight_default: NotRequired[Nullable[int]]
    r"""Default weight for the element"""
    weight_max: NotRequired[Nullable[int]]
    r"""Maximum weight for the element"""
    weight_min: NotRequired[Nullable[int]]
    r"""Minimum weight for the element"""


class GetGenerationByIDLoras(BaseModel):
    r"""Element used for the generation."""

    ak_uuid: Annotated[OptionalNullable[str], pydantic.Field(alias="akUUID")] = UNSET
    r"""Unique identifier for the element. Elements can be found from the List Elements endpoint."""

    base_model: Annotated[
        Optional[shared_sd_versions.SdVersions], pydantic.Field(alias="baseModel")
    ] = None
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""

    description: OptionalNullable[str] = UNSET
    r"""Description for the element"""

    name: OptionalNullable[str] = UNSET
    r"""Name of the element"""

    url_image: Annotated[OptionalNullable[str], pydantic.Field(alias="urlImage")] = (
        UNSET
    )
    r"""URL of the element image"""

    weight_default: Annotated[
        OptionalNullable[int], pydantic.Field(alias="weightDefault")
    ] = UNSET
    r"""Default weight for the element"""

    weight_max: Annotated[OptionalNullable[int], pydantic.Field(alias="weightMax")] = (
        UNSET
    )
    r"""Maximum weight for the element"""

    weight_min: Annotated[OptionalNullable[int], pydantic.Field(alias="weightMin")] = (
        UNSET
    )
    r"""Minimum weight for the element"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "akUUID",
            "baseModel",
            "description",
            "name",
            "urlImage",
            "weightDefault",
            "weightMax",
            "weightMin",
        ]
        nullable_fields = [
            "akUUID",
            "description",
            "name",
            "urlImage",
            "weightDefault",
            "weightMax",
            "weightMin",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GenerationElementsTypedDict(TypedDict):
    r"""This table captures the elements that are applied to Generations."""

    id: NotRequired[Nullable[int]]
    lora: NotRequired[Nullable[GetGenerationByIDLorasTypedDict]]
    r"""Element used for the generation."""
    weight_applied: NotRequired[Nullable[float]]


class GenerationElements(BaseModel):
    r"""This table captures the elements that are applied to Generations."""

    id: OptionalNullable[int] = UNSET

    lora: OptionalNullable[GetGenerationByIDLoras] = UNSET
    r"""Element used for the generation."""

    weight_applied: Annotated[
        OptionalNullable[float], pydantic.Field(alias="weightApplied")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "lora", "weightApplied"]
        nullable_fields = ["id", "lora", "weightApplied"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetGenerationByIDGenerationsTypedDict(TypedDict):
    r"""columns and relationships of \"generations\" """

    created_at: NotRequired[str]
    generated_images: NotRequired[List[GeneratedImagesTypedDict]]
    generation_elements: NotRequired[List[GenerationElementsTypedDict]]
    guidance_scale: NotRequired[Nullable[float]]
    id: NotRequired[Nullable[str]]
    image_height: NotRequired[int]
    image_width: NotRequired[int]
    inference_steps: NotRequired[Nullable[int]]
    init_strength: NotRequired[Nullable[float]]
    model_id: NotRequired[Nullable[str]]
    negative_prompt: NotRequired[Nullable[str]]
    photo_real: NotRequired[Nullable[bool]]
    r"""If photoReal feature was used."""
    photo_real_strength: NotRequired[Nullable[float]]
    r"""Depth of field of photoReal used. 0.55 is low, 0.5 is medium, and 0.45 is high. Default is 0.55."""
    preset_style: NotRequired[Nullable[shared_sd_generation_style.SdGenerationStyle]]
    r"""The style to generate images with. When photoReal is enabled, refer to the Guide section for a full list. When alchemy is disabled, use LEONARDO or NONE. When alchemy is enabled, use ANIME, CREATIVE, DYNAMIC, ENVIRONMENT, GENERAL, ILLUSTRATION, PHOTOGRAPHY, RAYTRACED, RENDER_3D, SKETCH_BW, SKETCH_COLOR, or NONE."""
    prompt: NotRequired[str]
    prompt_magic: NotRequired[Nullable[bool]]
    r"""If prompt magic was used."""
    prompt_magic_strength: NotRequired[Nullable[float]]
    r"""Strength of prompt magic used."""
    prompt_magic_version: NotRequired[Nullable[str]]
    r"""Version of prompt magic used."""
    public: NotRequired[bool]
    scheduler: NotRequired[shared_sd_generation_schedulers.SdGenerationSchedulers]
    r"""The scheduler to generate images with. Defaults to EULER_DISCRETE if not specified."""
    sd_version: NotRequired[shared_sd_versions.SdVersions]
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""
    seed: NotRequired[Nullable[int]]
    status: NotRequired[shared_job_status.JobStatus]
    r"""The status of the current task."""
    ultra: NotRequired[Nullable[bool]]
    r"""If ultra generation mode was used."""


class GetGenerationByIDGenerations(BaseModel):
    r"""columns and relationships of \"generations\" """

    created_at: Annotated[Optional[str], pydantic.Field(alias="createdAt")] = None

    generated_images: Optional[List[GeneratedImages]] = None

    generation_elements: Optional[List[GenerationElements]] = None

    guidance_scale: Annotated[
        OptionalNullable[float], pydantic.Field(alias="guidanceScale")
    ] = UNSET

    id: OptionalNullable[str] = UNSET

    image_height: Annotated[Optional[int], pydantic.Field(alias="imageHeight")] = None

    image_width: Annotated[Optional[int], pydantic.Field(alias="imageWidth")] = None

    inference_steps: Annotated[
        OptionalNullable[int], pydantic.Field(alias="inferenceSteps")
    ] = UNSET

    init_strength: Annotated[
        OptionalNullable[float], pydantic.Field(alias="initStrength")
    ] = UNSET

    model_id: Annotated[OptionalNullable[str], pydantic.Field(alias="modelId")] = UNSET

    negative_prompt: Annotated[
        OptionalNullable[str], pydantic.Field(alias="negativePrompt")
    ] = UNSET

    photo_real: Annotated[OptionalNullable[bool], pydantic.Field(alias="photoReal")] = (
        UNSET
    )
    r"""If photoReal feature was used."""

    photo_real_strength: Annotated[
        OptionalNullable[float], pydantic.Field(alias="photoRealStrength")
    ] = UNSET
    r"""Depth of field of photoReal used. 0.55 is low, 0.5 is medium, and 0.45 is high. Default is 0.55."""

    preset_style: Annotated[
        OptionalNullable[shared_sd_generation_style.SdGenerationStyle],
        pydantic.Field(alias="presetStyle"),
    ] = shared_sd_generation_style.SdGenerationStyle.DYNAMIC
    r"""The style to generate images with. When photoReal is enabled, refer to the Guide section for a full list. When alchemy is disabled, use LEONARDO or NONE. When alchemy is enabled, use ANIME, CREATIVE, DYNAMIC, ENVIRONMENT, GENERAL, ILLUSTRATION, PHOTOGRAPHY, RAYTRACED, RENDER_3D, SKETCH_BW, SKETCH_COLOR, or NONE."""

    prompt: Optional[str] = None

    prompt_magic: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="promptMagic")
    ] = UNSET
    r"""If prompt magic was used."""

    prompt_magic_strength: Annotated[
        OptionalNullable[float], pydantic.Field(alias="promptMagicStrength")
    ] = UNSET
    r"""Strength of prompt magic used."""

    prompt_magic_version: Annotated[
        OptionalNullable[str], pydantic.Field(alias="promptMagicVersion")
    ] = UNSET
    r"""Version of prompt magic used."""

    public: Optional[bool] = None

    scheduler: Optional[shared_sd_generation_schedulers.SdGenerationSchedulers] = None
    r"""The scheduler to generate images with. Defaults to EULER_DISCRETE if not specified."""

    sd_version: Annotated[
        Optional[shared_sd_versions.SdVersions], pydantic.Field(alias="sdVersion")
    ] = None
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""

    seed: OptionalNullable[int] = UNSET

    status: Optional[shared_job_status.JobStatus] = None
    r"""The status of the current task."""

    ultra: OptionalNullable[bool] = UNSET
    r"""If ultra generation mode was used."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "createdAt",
            "generated_images",
            "generation_elements",
            "guidanceScale",
            "id",
            "imageHeight",
            "imageWidth",
            "inferenceSteps",
            "initStrength",
            "modelId",
            "negativePrompt",
            "photoReal",
            "photoRealStrength",
            "presetStyle",
            "prompt",
            "promptMagic",
            "promptMagicStrength",
            "promptMagicVersion",
            "public",
            "scheduler",
            "sdVersion",
            "seed",
            "status",
            "ultra",
        ]
        nullable_fields = [
            "guidanceScale",
            "id",
            "inferenceSteps",
            "initStrength",
            "modelId",
            "negativePrompt",
            "photoReal",
            "photoRealStrength",
            "presetStyle",
            "promptMagic",
            "promptMagicStrength",
            "promptMagicVersion",
            "seed",
            "ultra",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetGenerationByIDResponseBodyTypedDict(TypedDict):
    r"""Responses for GET /generations/{id}"""

    generations_by_pk: NotRequired[Nullable[GetGenerationByIDGenerationsTypedDict]]
    r"""columns and relationships of \"generations\" """


class GetGenerationByIDResponseBody(BaseModel):
    r"""Responses for GET /generations/{id}"""

    generations_by_pk: OptionalNullable[GetGenerationByIDGenerations] = UNSET
    r"""columns and relationships of \"generations\" """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["generations_by_pk"]
        nullable_fields = ["generations_by_pk"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetGenerationByIDResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[GetGenerationByIDResponseBodyTypedDict]
    r"""Responses for GET /generations/{id}"""


class GetGenerationByIDResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[GetGenerationByIDResponseBody] = None
    r"""Responses for GET /generations/{id}"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class JobStatus(str, Enum):
    r"""The status of the current task."""

    PENDING = "PENDING"
    COMPLETE = "COMPLETE"
    FAILED = "FAILED"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UploadCanvasInitImageRequestBodyTypedDict(TypedDict):
    r"""Query parameters provided in the request body as a JSON object"""

    init_extension: str
    r"""Has to be png, jpg, jpeg, or webp."""
    mask_extension: str
    r"""Has to be png, jpg, jpeg, or webp."""


class UploadCanvasInitImageRequestBody(BaseModel):
    r"""Query parameters provided in the request body as a JSON object"""

    init_extension: Annotated[str, pydantic.Field(alias="initExtension")]
    r"""Has to be png, jpg, jpeg, or webp."""

    mask_extension: Annotated[str, pydantic.Field(alias="maskExtension")]
    r"""Has to be png, jpg, jpeg, or webp."""


class CanvasInitImageUploadOutputTypedDict(TypedDict):
    init_fields: NotRequired[Nullable[str]]
    init_image_id: NotRequired[Nullable[str]]
    init_key: NotRequired[Nullable[str]]
    init_url: NotRequired[Nullable[str]]
    mask_fields: NotRequired[Nullable[str]]
    mask_image_id: NotRequired[Nullable[str]]
    mask_key: NotRequired[Nullable[str]]
    mask_url: NotRequired[Nullable[str]]


class CanvasInitImageUploadOutput(BaseModel):
    init_fields: Annotated[
        OptionalNullable[str], pydantic.Field(alias="initFields")
    ] = UNSET

    init_image_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="initImageId")
    ] = UNSET

    init_key: Annotated[OptionalNullable[str], pydantic.Field(alias="initKey")] = UNSET

    init_url: Annotated[OptionalNullable[str], pydantic.Field(alias="initUrl")] = UNSET

    mask_fields: Annotated[
        OptionalNullable[str], pydantic.Field(alias="maskFields")
    ] = UNSET

    mask_image_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="maskImageId")
    ] = UNSET

    mask_key: Annotated[OptionalNullable[str], pydantic.Field(alias="maskKey")] = UNSET

    mask_url: Annotated[OptionalNullable[str], pydantic.Field(alias="maskUrl")] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "initFields",
            "initImageId",
            "initKey",
            "initUrl",
            "maskFields",
            "maskImageId",
            "maskKey",
            "maskUrl",
        ]
        nullable_fields = [
            "initFields",
            "initImageId",
            "initKey",
            "initUrl",
            "maskFields",
            "maskImageId",
            "maskKey",
            "maskUrl",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UploadCanvasInitImageResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /canvas-init-image"""

    upload_canvas_init_image: NotRequired[
        Nullable[CanvasInitImageUploadOutputTypedDict]
    ]


class UploadCanvasInitImageResponseBody(BaseModel):
    r"""Responses for POST /canvas-init-image"""

    upload_canvas_init_image: Annotated[
        OptionalNullable[CanvasInitImageUploadOutput],
        pydantic.Field(alias="uploadCanvasInitImage"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["uploadCanvasInitImage"]
        nullable_fields = ["uploadCanvasInitImage"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UploadCanvasInitImageResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[UploadCanvasInitImageResponseBodyTypedDict]
    r"""Responses for POST /canvas-init-image"""


class UploadCanvasInitImageResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[UploadCanvasInitImageResponseBody] = None
    r"""Responses for POST /canvas-init-image"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.models.shared import sd_versions as shared_sd_versions
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class LorasTypedDict(TypedDict):
    r"""columns and relationships of \"elements\"."""

    ak_uuid: NotRequired[Nullable[str]]
    r"""Unique identifier for the element. Elements can be found from the List Elements endpoint."""
    base_model: NotRequired[shared_sd_versions.SdVersions]
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""
    creator_name: NotRequired[Nullable[str]]
    r"""Name of the creator of the element"""
    description: NotRequired[Nullable[str]]
    r"""Description for the element"""
    name: NotRequired[Nullable[str]]
    r"""Name of the element"""
    url_image: NotRequired[Nullable[str]]
    r"""URL of the element image"""
    weight_default: NotRequired[Nullable[int]]
    r"""Default weight for the element"""
    weight_max: NotRequired[Nullable[int]]
    r"""Maximum weight for the element"""
    weight_min: NotRequired[Nullable[int]]
    r"""Minimum weight for the element"""


class Loras(BaseModel):
    r"""columns and relationships of \"elements\"."""

    ak_uuid: Annotated[OptionalNullable[str], pydantic.Field(alias="akUUID")] = UNSET
    r"""Unique identifier for the element. Elements can be found from the List Elements endpoint."""

    base_model: Annotated[
        Optional[shared_sd_versions.SdVersions], pydantic.Field(alias="baseModel")
    ] = None
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5. Also includes SDXL and SDXL Lightning models"""

    creator_name: Annotated[
        OptionalNullable[str], pydantic.Field(alias="creatorName")
    ] = UNSET
    r"""Name of the creator of the element"""

    description: OptionalNullable[str] = UNSET
    r"""Description for the element"""

    name: OptionalNullable[str] = UNSET
    r"""Name of the element"""

    url_image: Annotated[OptionalNullable[str], pydantic.Field(alias="urlImage")] = (
        UNSET
    )
    r"""URL of the element image"""

    weight_default: Annotated[
        OptionalNullable[int], pydantic.Field(alias="weightDefault")
    ] = UNSET
    r"""Default weight for the element"""

    weight_max: Annotated[OptionalNullable[int], pydantic.Field(alias="weightMax")] = (
        UNSET
    )
    r"""Maximum weight for the element"""

    weight_min: Annotated[OptionalNullable[int], pydantic.Field(alias="weightMin")] = (
        UNSET
    )
    r"""Minimum weight for the element"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "akUUID",
            "baseModel",
            "creatorName",
            "description",
            "name",
            "urlImage",
            "weightDefault",
            "weightMax",
            "weightMin",
        ]
        nullable_fields = [
            "akUUID",
            "creatorName",
            "description",
            "name",
            "urlImage",
            "weightDefault",
            "weightMax",
            "weightMin",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ListElementsResponseBodyTypedDict(TypedDict):
    r"""Responses for GET /api/rest/v1/elements."""

    loras: NotRequired[List[LorasTypedDict]]


class ListElementsResponseBody(BaseModel):
    r"""Responses for GET /api/rest/v1/elements."""

    loras: Optional[List[Loras]] = None


class ListElementsResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[ListElementsResponseBodyTypedDict]
    r"""Responses for GET /api/rest/v1/elements."""


class ListElementsResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[ListElementsResponseBody] = None
    r"""Responses for GET /api/rest/v1/elements."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class InitImageType(str, Enum):
    r"""Type indicating whether the init image is uploaded or generated."""

    GENERATED = "GENERATED"
    UPLOADED = "UPLOADED"


class StrengthType(str, Enum):
    r"""Strength type for the controlnet. Can only be used for Style, Character and Content Reference controlnets."""

    LOW = "Low"
    MID = "Mid"
    HIGH = "High"
    ULTRA = "Ultra"
    MAX = "Max"


class ControlnetInputTypedDict(TypedDict):
    init_image_id: NotRequired[str]
    r"""The ID of the init image"""
    init_image_type: NotRequired[InitImageType]
    r"""Type indicating whether the init image is uploaded or generated."""
    preprocessor_id: NotRequired[float]
    r"""ID of the controlnet. A list of compatible IDs can be found in our guides."""
    strength_type: NotRequired[Nullable[StrengthType]]
    r"""Strength type for the controlnet. Can only be used for Style, Character and Content Reference controlnets."""
    weight: NotRequired[Nullable[float]]
    r"""Weight for the controlnet"""


class ControlnetInput(BaseModel):
    init_image_id: Annotated[Optional[str], pydantic.Field(alias="initImageId")] = None
    r"""The ID of the init image"""

    init_image_type: Annotated[
        Optional[InitImageType], pydantic.Field(alias="initImageType")
    ] = None
    r"""Type indicating whether the init image is uploaded or generated."""

    preprocessor_id: Annotated[
        Optional[float], pydantic.Field(alias="preprocessorId")
    ] = None
    r"""ID of the controlnet. A list of compatible IDs can be found in our guides."""

    strength_type: Annotated[
        OptionalNullable[StrengthType], pydantic.Field(alias="strengthType")
    ] = UNSET
    r"""Strength type for the controlnet. Can only be used for Style, Character and Content Reference controlnets."""

    weight: OptionalNullable[float] = UNSET
    r"""Weight for the controlnet"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "initImageId",
            "initImageType",
            "preprocessorId",
            "strengthType",
            "weight",
        ]
        nullable_fields = ["strengthType", "weight"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .createdataset import (
    CreateDatasetRequestBody,
    CreateDatasetRequestBodyTypedDict,
    CreateDatasetResponse,
    CreateDatasetResponseBody,
    CreateDatasetResponseBodyTypedDict,
    CreateDatasetResponseTypedDict,
    Datasets,
    DatasetsTypedDict,
)
from .createelement import (
    CreateElementRequestBody,
    CreateElementRequestBodyTypedDict,
    CreateElementResponse,
    CreateElementResponseBody,
    CreateElementResponseBodyTypedDict,
    CreateElementResponseTypedDict,
    SDTrainingOutput,
    SDTrainingOutputTypedDict,
    SdVersions,
)
from .creategeneration import (
    CreateGenerationRequestBody,
    CreateGenerationRequestBodyTypedDict,
    CreateGenerationResponse,
    CreateGenerationResponseBody,
    CreateGenerationResponseBodyTypedDict,
    CreateGenerationResponseTypedDict,
    SDGenerationOutput,
    SDGenerationOutputTypedDict,
    TransparencyType,
)
from .createlcmgeneration import (
    CreateLCMGenerationRequestBody,
    CreateLCMGenerationRequestBodyTypedDict,
    CreateLCMGenerationResponse,
    CreateLCMGenerationResponseBody,
    CreateLCMGenerationResponseBodyTypedDict,
    CreateLCMGenerationResponseTypedDict,
    LcmGenerationOutput,
    LcmGenerationOutputTypedDict,
)
from .createmodel import (
    CreateModelRequestBody,
    CreateModelRequestBodyTypedDict,
    CreateModelResponse,
    CreateModelResponseBody,
    CreateModelResponseBodyTypedDict,
    CreateModelResponseTypedDict,
    CreateModelSDTrainingOutput,
    CreateModelSDTrainingOutputTypedDict,
    CreateModelSdVersions,
)
from .createsvdmotiongeneration import (
    CreateSVDMotionGenerationRequestBody,
    CreateSVDMotionGenerationRequestBodyTypedDict,
    CreateSVDMotionGenerationResponse,
    CreateSVDMotionGenerationResponseBody,
    CreateSVDMotionGenerationResponseBodyTypedDict,
    CreateSVDMotionGenerationResponseTypedDict,
    MotionSvdGenerationOutput,
    MotionSvdGenerationOutputTypedDict,
)
from .createtexturegeneration import (
    CreateTextureGenerationRequestBody,
    CreateTextureGenerationRequestBodyTypedDict,
    CreateTextureGenerationResponse,
    CreateTextureGenerationResponseBody,
    CreateTextureGenerationResponseBodyTypedDict,
    CreateTextureGenerationResponseTypedDict,
    TextureGenerationJobOutput,
    TextureGenerationJobOutputTypedDict,
)
from .createuniversalupscalerjob import (
    CreateUniversalUpscalerJobRequestBody,
    CreateUniversalUpscalerJobRequestBodyTypedDict,
    CreateUniversalUpscalerJobResponse,
    CreateUniversalUpscalerJobResponseBody,
    CreateUniversalUpscalerJobResponseBodyTypedDict,
    CreateUniversalUpscalerJobResponseTypedDict,
    UniversalUpscalerOutput,
    UniversalUpscalerOutputTypedDict,
)
from .createvariationnobg import (
    CreateVariationNoBGRequestBody,
    CreateVariationNoBGRequestBodyTypedDict,
    CreateVariationNoBGResponse,
    CreateVariationNoBGResponseBody,
    CreateVariationNoBGResponseBodyTypedDict,
    CreateVariationNoBGResponseTypedDict,
    SDUpscaleJobOutput,
    SDUpscaleJobOutputTypedDict,
)
from .createvariationunzoom import (
    CreateVariationUnzoomRequestBody,
    CreateVariationUnzoomRequestBodyTypedDict,
    CreateVariationUnzoomResponse,
    CreateVariationUnzoomResponseBody,
    CreateVariationUnzoomResponseBodyTypedDict,
    CreateVariationUnzoomResponseTypedDict,
    SDUnzoomOutput,
    SDUnzoomOutputTypedDict,
)
from .createvariationupscale import (
    CreateVariationUpscaleRequestBody,
    CreateVariationUpscaleRequestBodyTypedDict,
    CreateVariationUpscaleResponse,
    CreateVariationUpscaleResponseBody,
    CreateVariationUpscaleResponseBodyTypedDict,
    CreateVariationUpscaleResponseTypedDict,
    CreateVariationUpscaleSDUpscaleJobOutput,
    CreateVariationUpscaleSDUpscaleJobOutputTypedDict,
)
from .delete3dmodelbyid import (
    Delete3DModelByIDRequest,
    Delete3DModelByIDRequestBody,
    Delete3DModelByIDRequestBodyTypedDict,
    Delete3DModelByIDRequestTypedDict,
    Delete3DModelByIDResponse,
    Delete3DModelByIDResponseBody,
    Delete3DModelByIDResponseBodyTypedDict,
    Delete3DModelByIDResponseTypedDict,
    ModelAssets,
    ModelAssetsTypedDict,
)
from .deletedatasetbyid import (
    DeleteDatasetByIDDatasets,
    DeleteDatasetByIDDatasetsTypedDict,
    DeleteDatasetByIDRequest,
    DeleteDatasetByIDRequestTypedDict,
    DeleteDatasetByIDResponse,
    DeleteDatasetByIDResponseBody,
    DeleteDatasetByIDResponseBodyTypedDict,
    DeleteDatasetByIDResponseTypedDict,
)
from .deleteelementbyid import (
    DeleteElementByIDRequest,
    DeleteElementByIDRequestTypedDict,
    DeleteElementByIDResponse,
    DeleteElementByIDResponseBody,
    DeleteElementByIDResponseBodyTypedDict,
    DeleteElementByIDResponseTypedDict,
    UserLoras,
    UserLorasTypedDict,
)
from .deletegenerationbyid import (
    DeleteGenerationByIDRequest,
    DeleteGenerationByIDRequestTypedDict,
    DeleteGenerationByIDResponse,
    DeleteGenerationByIDResponseBody,
    DeleteGenerationByIDResponseBodyTypedDict,
    DeleteGenerationByIDResponseTypedDict,
    Generations,
    GenerationsTypedDict,
)
from .deleteinitimagebyid import (
    DeleteInitImageByIDRequest,
    DeleteInitImageByIDRequestTypedDict,
    DeleteInitImageByIDResponse,
    DeleteInitImageByIDResponseBody,
    DeleteInitImageByIDResponseBodyTypedDict,
    DeleteInitImageByIDResponseTypedDict,
    InitImages,
    InitImagesTypedDict,
)
from .deletemodelbyid import (
    CustomModels,
    CustomModelsTypedDict,
    DeleteModelByIDRequest,
    DeleteModelByIDRequestTypedDict,
    DeleteModelByIDResponse,
    DeleteModelByIDResponseBody,
    DeleteModelByIDResponseBodyTypedDict,
    DeleteModelByIDResponseTypedDict,
)
from .deletetexturegenerationbyid import (
    DeleteTextureGenerationByIDRequest,
    DeleteTextureGenerationByIDRequestBody,
    DeleteTextureGenerationByIDRequestBodyTypedDict,
    DeleteTextureGenerationByIDRequestTypedDict,
    DeleteTextureGenerationByIDResponse,
    DeleteTextureGenerationByIDResponseBody,
    DeleteTextureGenerationByIDResponseBodyTypedDict,
    DeleteTextureGenerationByIDResponseTypedDict,
    ModelAssetTextureGenerations,
    ModelAssetTextureGenerationsTypedDict,
)
from .get3dmodelbyid import (
    Get3DModelByIDModelAssets,
    Get3DModelByIDModelAssetsTypedDict,
    Get3DModelByIDRequest,
    Get3DModelByIDRequestBody,
    Get3DModelByIDRequestBodyTypedDict,
    Get3DModelByIDRequestTypedDict,
    Get3DModelByIDResponse,
    Get3DModelByIDResponseBody,
    Get3DModelByIDResponseBodyTypedDict,
    Get3DModelByIDResponseTypedDict,
)
from .get3dmodelsbyuserid import (
    Get3DModelsByUserIDModelAssets,
    Get3DModelsByUserIDModelAssetsTypedDict,
    Get3DModelsByUserIDRequest,
    Get3DModelsByUserIDRequestBody,
    Get3DModelsByUserIDRequestBodyTypedDict,
    Get3DModelsByUserIDRequestTypedDict,
    Get3DModelsByUserIDResponse,
    Get3DModelsByUserIDResponseBody,
    Get3DModelsByUserIDResponseBodyTypedDict,
    Get3DModelsByUserIDResponseTypedDict,
)
from .getcustomelementsbyuserid import (
    GetCustomElementsByUserIDRequest,
    GetCustomElementsByUserIDRequestTypedDict,
    GetCustomElementsByUserIDResponse,
    GetCustomElementsByUserIDResponseBody,
    GetCustomElementsByUserIDResponseBodyTypedDict,
    GetCustomElementsByUserIDResponseTypedDict,
    GetCustomElementsByUserIDUserLoras,
    GetCustomElementsByUserIDUserLorasTypedDict,
)
from .getcustommodelsbyuserid import (
    GetCustomModelsByUserIDCustomModels,
    GetCustomModelsByUserIDCustomModelsTypedDict,
    GetCustomModelsByUserIDRequest,
    GetCustomModelsByUserIDRequestTypedDict,
    GetCustomModelsByUserIDResponse,
    GetCustomModelsByUserIDResponseBody,
    GetCustomModelsByUserIDResponseBodyTypedDict,
    GetCustomModelsByUserIDResponseTypedDict,
)
from .getdatasetbyid import (
    DatasetImages,
    DatasetImagesTypedDict,
    GetDatasetByIDDatasets,
    GetDatasetByIDDatasetsTypedDict,
    GetDatasetByIDRequest,
    GetDatasetByIDRequestTypedDict,
    GetDatasetByIDResponse,
    GetDatasetByIDResponseBody,
    GetDatasetByIDResponseBodyTypedDict,
    GetDatasetByIDResponseTypedDict,
)
from .getelementbyid import (
    GetElementByIDRequest,
    GetElementByIDRequestTypedDict,
    GetElementByIDResponse,
    GetElementByIDResponseBody,
    GetElementByIDResponseBodyTypedDict,
    GetElementByIDResponseTypedDict,
    GetElementByIDUserLoras,
    GetElementByIDUserLorasTypedDict,
)
from .getgenerationbyid import (
    GeneratedImages,
    GeneratedImagesTypedDict,
    GenerationElements,
    GenerationElementsTypedDict,
    GetGenerationByIDGeneratedImageVariationGeneric,
    GetGenerationByIDGeneratedImageVariationGenericTypedDict,
    GetGenerationByIDGenerations,
    GetGenerationByIDGenerationsTypedDict,
    GetGenerationByIDLoras,
    GetGenerationByIDLorasTypedDict,
    GetGenerationByIDRequest,
    GetGenerationByIDRequestTypedDict,
    GetGenerationByIDResponse,
    GetGenerationByIDResponseBody,
    GetGenerationByIDResponseBodyTypedDict,
    GetGenerationByIDResponseTypedDict,
)
from .getgenerationsbyuserid import (
    Elements,
    ElementsTypedDict,
    GetGenerationsByUserIDGeneratedImageVariationGeneric,
    GetGenerationsByUserIDGeneratedImageVariationGenericTypedDict,
    GetGenerationsByUserIDGeneratedImages,
    GetGenerationsByUserIDGeneratedImagesTypedDict,
    GetGenerationsByUserIDGenerationElements,
    GetGenerationsByUserIDGenerationElementsTypedDict,
    GetGenerationsByUserIDGenerations,
    GetGenerationsByUserIDGenerationsTypedDict,
    GetGenerationsByUserIDRequest,
    GetGenerationsByUserIDRequestTypedDict,
    GetGenerationsByUserIDResponse,
    GetGenerationsByUserIDResponseBody,
    GetGenerationsByUserIDResponseBodyTypedDict,
    GetGenerationsByUserIDResponseTypedDict,
)
from .getinitimagebyid import (
    GetInitImageByIDInitImages,
    GetInitImageByIDInitImagesTypedDict,
    GetInitImageByIDRequest,
    GetInitImageByIDRequestTypedDict,
    GetInitImageByIDResponse,
    GetInitImageByIDResponseBody,
    GetInitImageByIDResponseBodyTypedDict,
    GetInitImageByIDResponseTypedDict,
)
from .getmodelbyid import (
    GetModelByIDCustomModels,
    GetModelByIDCustomModelsTypedDict,
    GetModelByIDRequest,
    GetModelByIDRequestTypedDict,
    GetModelByIDResponse,
    GetModelByIDResponseBody,
    GetModelByIDResponseBodyTypedDict,
    GetModelByIDResponseTypedDict,
)
from .gettexturegenerationbyid import (
    GetTextureGenerationByIDModelAssetTextureGenerations,
    GetTextureGenerationByIDModelAssetTextureGenerationsTypedDict,
    GetTextureGenerationByIDRequest,
    GetTextureGenerationByIDRequestBody,
    GetTextureGenerationByIDRequestBodyTypedDict,
    GetTextureGenerationByIDRequestTypedDict,
    GetTextureGenerationByIDResponse,
    GetTextureGenerationByIDResponseBody,
    GetTextureGenerationByIDResponseBodyTypedDict,
    GetTextureGenerationByIDResponseTypedDict,
    ModelAssetTextureImages,
    ModelAssetTextureImagesTypedDict,
)
from .gettexturegenerationsbymodelid import (
    GetTextureGenerationsByModelIDModelAssetTextureGenerations,
    GetTextureGenerationsByModelIDModelAssetTextureGenerationsTypedDict,
    GetTextureGenerationsByModelIDModelAssetTextureImages,
    GetTextureGenerationsByModelIDModelAssetTextureImagesTypedDict,
    GetTextureGenerationsByModelIDRequest,
    GetTextureGenerationsByModelIDRequestBody,
    GetTextureGenerationsByModelIDRequestBodyTypedDict,
    GetTextureGenerationsByModelIDRequestTypedDict,
    GetTextureGenerationsByModelIDResponse,
    GetTextureGenerationsByModelIDResponseBody,
    GetTextureGenerationsByModelIDResponseBodyTypedDict,
    GetTextureGenerationsByModelIDResponseTypedDict,
)
from .getuserself import (
    GetUserSelfResponse,
    GetUserSelfResponseBody,
    GetUserSelfResponseBodyTypedDict,
    GetUserSelfResponseTypedDict,
    UserDetails,
    UserDetailsTypedDict,
    Users,
    UsersTypedDict,
)
from .getvariationbyid import (
    GeneratedImageVariationGeneric,
    GeneratedImageVariationGenericTypedDict,
    GetVariationByIDRequest,
    GetVariationByIDRequestTypedDict,
    GetVariationByIDResponse,
    GetVariationByIDResponseBody,
    GetVariationByIDResponseBodyTypedDict,
    GetVariationByIDResponseTypedDict,
)
from .listelements import (
    ListElementsResponse,
    ListElementsResponseBody,
    ListElementsResponseBodyTypedDict,
    ListElementsResponseTypedDict,
    Loras,
    LorasTypedDict,
)
from .listplatformmodels import (
    ListPlatformModelsCustomModels,
    ListPlatformModelsCustomModelsTypedDict,
    ListPlatformModelsGeneratedImages,
    ListPlatformModelsGeneratedImagesTypedDict,
    ListPlatformModelsResponse,
    ListPlatformModelsResponseBody,
    ListPlatformModelsResponseBodyTypedDict,
    ListPlatformModelsResponseTypedDict,
)
from .performalchemyupscalelcm import (
    PerformAlchemyUpscaleLCMLCMGenerationOutput,
    PerformAlchemyUpscaleLCMLCMGenerationOutputTypedDict,
    PerformAlchemyUpscaleLCMRequestBody,
    PerformAlchemyUpscaleLCMRequestBodyTypedDict,
    PerformAlchemyUpscaleLCMResponse,
    PerformAlchemyUpscaleLCMResponseBody,
    PerformAlchemyUpscaleLCMResponseBodyTypedDict,
    PerformAlchemyUpscaleLCMResponseTypedDict,
)
from .performinpaintinglcm import (
    PerformInpaintingLCMLCMGenerationOutput,
    PerformInpaintingLCMLCMGenerationOutputTypedDict,
    PerformInpaintingLCMRequestBody,
    PerformInpaintingLCMRequestBodyTypedDict,
    PerformInpaintingLCMResponse,
    PerformInpaintingLCMResponseBody,
    PerformInpaintingLCMResponseBodyTypedDict,
    PerformInpaintingLCMResponseTypedDict,
)
from .performinstantrefine import (
    PerformInstantRefineLcmGenerationOutput,
    PerformInstantRefineLcmGenerationOutputTypedDict,
    PerformInstantRefineRequestBody,
    PerformInstantRefineRequestBodyTypedDict,
    PerformInstantRefineResponse,
    PerformInstantRefineResponseBody,
    PerformInstantRefineResponseBodyTypedDict,
    PerformInstantRefineResponseTypedDict,
)
from .pricingcalculator import (
    CalculateProductionAPIServiceCost,
    CalculateProductionAPIServiceCostTypedDict,
    Object,
    ObjectTypedDict,
    PricingCalculatorObject,
    PricingCalculatorObjectTypedDict,
    PricingCalculatorPricingCalculatorObject,
    PricingCalculatorPricingCalculatorObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestObject,
    PricingCalculatorPricingCalculatorRequestObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObjectTypedDict,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObject,
    PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObjectTypedDict,
    PricingCalculatorRequestBody,
    PricingCalculatorRequestBodyTypedDict,
    PricingCalculatorResponse,
    PricingCalculatorResponseBody,
    PricingCalculatorResponseBodyTypedDict,
    PricingCalculatorResponseTypedDict,
)
from .promptimprove import (
    PromptGenerationOutput,
    PromptGenerationOutputTypedDict,
    PromptImproveRequestBody,
    PromptImproveRequestBodyTypedDict,
    PromptImproveResponse,
    PromptImproveResponseBody,
    PromptImproveResponseBodyTypedDict,
    PromptImproveResponseTypedDict,
)
from .promptrandom import (
    PromptRandomPromptGenerationOutput,
    PromptRandomPromptGenerationOutputTypedDict,
    PromptRandomResponse,
    PromptRandomResponseBody,
    PromptRandomResponseBodyTypedDict,
    PromptRandomResponseTypedDict,
)
from .uploadcanvasinitimage import (
    CanvasInitImageUploadOutput,
    CanvasInitImageUploadOutputTypedDict,
    UploadCanvasInitImageRequestBody,
    UploadCanvasInitImageRequestBodyTypedDict,
    UploadCanvasInitImageResponse,
    UploadCanvasInitImageResponseBody,
    UploadCanvasInitImageResponseBodyTypedDict,
    UploadCanvasInitImageResponseTypedDict,
)
from .uploaddatasetimage import (
    DatasetUploadOutput,
    DatasetUploadOutputTypedDict,
    UploadDatasetImageRequest,
    UploadDatasetImageRequestBody,
    UploadDatasetImageRequestBodyTypedDict,
    UploadDatasetImageRequestTypedDict,
    UploadDatasetImageResponse,
    UploadDatasetImageResponseBody,
    UploadDatasetImageResponseBodyTypedDict,
    UploadDatasetImageResponseTypedDict,
)
from .uploaddatasetimagefromgen import (
    DatasetGenUploadOutput,
    DatasetGenUploadOutputTypedDict,
    UploadDatasetImageFromGenRequest,
    UploadDatasetImageFromGenRequestBody,
    UploadDatasetImageFromGenRequestBodyTypedDict,
    UploadDatasetImageFromGenRequestTypedDict,
    UploadDatasetImageFromGenResponse,
    UploadDatasetImageFromGenResponseBody,
    UploadDatasetImageFromGenResponseBodyTypedDict,
    UploadDatasetImageFromGenResponseTypedDict,
)
from .uploadinitimage import (
    InitImageUploadOutput,
    InitImageUploadOutputTypedDict,
    UploadInitImageRequestBody,
    UploadInitImageRequestBodyTypedDict,
    UploadInitImageResponse,
    UploadInitImageResponseBody,
    UploadInitImageResponseBodyTypedDict,
    UploadInitImageResponseTypedDict,
)
from .uploadmodelasset import (
    ModelAssetUploadOutput,
    ModelAssetUploadOutputTypedDict,
    UploadModelAssetRequestBody,
    UploadModelAssetRequestBodyTypedDict,
    UploadModelAssetResponse,
    UploadModelAssetResponseBody,
    UploadModelAssetResponseBodyTypedDict,
    UploadModelAssetResponseTypedDict,
)

__all__ = [
    "CalculateProductionAPIServiceCost",
    "CalculateProductionAPIServiceCostTypedDict",
    "CanvasInitImageUploadOutput",
    "CanvasInitImageUploadOutputTypedDict",
    "CreateDatasetRequestBody",
    "CreateDatasetRequestBodyTypedDict",
    "CreateDatasetResponse",
    "CreateDatasetResponseBody",
    "CreateDatasetResponseBodyTypedDict",
    "CreateDatasetResponseTypedDict",
    "CreateElementRequestBody",
    "CreateElementRequestBodyTypedDict",
    "CreateElementResponse",
    "CreateElementResponseBody",
    "CreateElementResponseBodyTypedDict",
    "CreateElementResponseTypedDict",
    "CreateGenerationRequestBody",
    "CreateGenerationRequestBodyTypedDict",
    "CreateGenerationResponse",
    "CreateGenerationResponseBody",
    "CreateGenerationResponseBodyTypedDict",
    "CreateGenerationResponseTypedDict",
    "CreateLCMGenerationRequestBody",
    "CreateLCMGenerationRequestBodyTypedDict",
    "CreateLCMGenerationResponse",
    "CreateLCMGenerationResponseBody",
    "CreateLCMGenerationResponseBodyTypedDict",
    "CreateLCMGenerationResponseTypedDict",
    "CreateModelRequestBody",
    "CreateModelRequestBodyTypedDict",
    "CreateModelResponse",
    "CreateModelResponseBody",
    "CreateModelResponseBodyTypedDict",
    "CreateModelResponseTypedDict",
    "CreateModelSDTrainingOutput",
    "CreateModelSDTrainingOutputTypedDict",
    "CreateModelSdVersions",
    "CreateSVDMotionGenerationRequestBody",
    "CreateSVDMotionGenerationRequestBodyTypedDict",
    "CreateSVDMotionGenerationResponse",
    "CreateSVDMotionGenerationResponseBody",
    "CreateSVDMotionGenerationResponseBodyTypedDict",
    "CreateSVDMotionGenerationResponseTypedDict",
    "CreateTextureGenerationRequestBody",
    "CreateTextureGenerationRequestBodyTypedDict",
    "CreateTextureGenerationResponse",
    "CreateTextureGenerationResponseBody",
    "CreateTextureGenerationResponseBodyTypedDict",
    "CreateTextureGenerationResponseTypedDict",
    "CreateUniversalUpscalerJobRequestBody",
    "CreateUniversalUpscalerJobRequestBodyTypedDict",
    "CreateUniversalUpscalerJobResponse",
    "CreateUniversalUpscalerJobResponseBody",
    "CreateUniversalUpscalerJobResponseBodyTypedDict",
    "CreateUniversalUpscalerJobResponseTypedDict",
    "CreateVariationNoBGRequestBody",
    "CreateVariationNoBGRequestBodyTypedDict",
    "CreateVariationNoBGResponse",
    "CreateVariationNoBGResponseBody",
    "CreateVariationNoBGResponseBodyTypedDict",
    "CreateVariationNoBGResponseTypedDict",
    "CreateVariationUnzoomRequestBody",
    "CreateVariationUnzoomRequestBodyTypedDict",
    "CreateVariationUnzoomResponse",
    "CreateVariationUnzoomResponseBody",
    "CreateVariationUnzoomResponseBodyTypedDict",
    "CreateVariationUnzoomResponseTypedDict",
    "CreateVariationUpscaleRequestBody",
    "CreateVariationUpscaleRequestBodyTypedDict",
    "CreateVariationUpscaleResponse",
    "CreateVariationUpscaleResponseBody",
    "CreateVariationUpscaleResponseBodyTypedDict",
    "CreateVariationUpscaleResponseTypedDict",
    "CreateVariationUpscaleSDUpscaleJobOutput",
    "CreateVariationUpscaleSDUpscaleJobOutputTypedDict",
    "CustomModels",
    "CustomModelsTypedDict",
    "DatasetGenUploadOutput",
    "DatasetGenUploadOutputTypedDict",
    "DatasetImages",
    "DatasetImagesTypedDict",
    "DatasetUploadOutput",
    "DatasetUploadOutputTypedDict",
    "Datasets",
    "DatasetsTypedDict",
    "Delete3DModelByIDRequest",
    "Delete3DModelByIDRequestBody",
    "Delete3DModelByIDRequestBodyTypedDict",
    "Delete3DModelByIDRequestTypedDict",
    "Delete3DModelByIDResponse",
    "Delete3DModelByIDResponseBody",
    "Delete3DModelByIDResponseBodyTypedDict",
    "Delete3DModelByIDResponseTypedDict",
    "DeleteDatasetByIDDatasets",
    "DeleteDatasetByIDDatasetsTypedDict",
    "DeleteDatasetByIDRequest",
    "DeleteDatasetByIDRequestTypedDict",
    "DeleteDatasetByIDResponse",
    "DeleteDatasetByIDResponseBody",
    "DeleteDatasetByIDResponseBodyTypedDict",
    "DeleteDatasetByIDResponseTypedDict",
    "DeleteElementByIDRequest",
    "DeleteElementByIDRequestTypedDict",
    "DeleteElementByIDResponse",
    "DeleteElementByIDResponseBody",
    "DeleteElementByIDResponseBodyTypedDict",
    "DeleteElementByIDResponseTypedDict",
    "DeleteGenerationByIDRequest",
    "DeleteGenerationByIDRequestTypedDict",
    "DeleteGenerationByIDResponse",
    "DeleteGenerationByIDResponseBody",
    "DeleteGenerationByIDResponseBodyTypedDict",
    "DeleteGenerationByIDResponseTypedDict",
    "DeleteInitImageByIDRequest",
    "DeleteInitImageByIDRequestTypedDict",
    "DeleteInitImageByIDResponse",
    "DeleteInitImageByIDResponseBody",
    "DeleteInitImageByIDResponseBodyTypedDict",
    "DeleteInitImageByIDResponseTypedDict",
    "DeleteModelByIDRequest",
    "DeleteModelByIDRequestTypedDict",
    "DeleteModelByIDResponse",
    "DeleteModelByIDResponseBody",
    "DeleteModelByIDResponseBodyTypedDict",
    "DeleteModelByIDResponseTypedDict",
    "DeleteTextureGenerationByIDRequest",
    "DeleteTextureGenerationByIDRequestBody",
    "DeleteTextureGenerationByIDRequestBodyTypedDict",
    "DeleteTextureGenerationByIDRequestTypedDict",
    "DeleteTextureGenerationByIDResponse",
    "DeleteTextureGenerationByIDResponseBody",
    "DeleteTextureGenerationByIDResponseBodyTypedDict",
    "DeleteTextureGenerationByIDResponseTypedDict",
    "Elements",
    "ElementsTypedDict",
    "GeneratedImageVariationGeneric",
    "GeneratedImageVariationGenericTypedDict",
    "GeneratedImages",
    "GeneratedImagesTypedDict",
    "GenerationElements",
    "GenerationElementsTypedDict",
    "Generations",
    "GenerationsTypedDict",
    "Get3DModelByIDModelAssets",
    "Get3DModelByIDModelAssetsTypedDict",
    "Get3DModelByIDRequest",
    "Get3DModelByIDRequestBody",
    "Get3DModelByIDRequestBodyTypedDict",
    "Get3DModelByIDRequestTypedDict",
    "Get3DModelByIDResponse",
    "Get3DModelByIDResponseBody",
    "Get3DModelByIDResponseBodyTypedDict",
    "Get3DModelByIDResponseTypedDict",
    "Get3DModelsByUserIDModelAssets",
    "Get3DModelsByUserIDModelAssetsTypedDict",
    "Get3DModelsByUserIDRequest",
    "Get3DModelsByUserIDRequestBody",
    "Get3DModelsByUserIDRequestBodyTypedDict",
    "Get3DModelsByUserIDRequestTypedDict",
    "Get3DModelsByUserIDResponse",
    "Get3DModelsByUserIDResponseBody",
    "Get3DModelsByUserIDResponseBodyTypedDict",
    "Get3DModelsByUserIDResponseTypedDict",
    "GetCustomElementsByUserIDRequest",
    "GetCustomElementsByUserIDRequestTypedDict",
    "GetCustomElementsByUserIDResponse",
    "GetCustomElementsByUserIDResponseBody",
    "GetCustomElementsByUserIDResponseBodyTypedDict",
    "GetCustomElementsByUserIDResponseTypedDict",
    "GetCustomElementsByUserIDUserLoras",
    "GetCustomElementsByUserIDUserLorasTypedDict",
    "GetCustomModelsByUserIDCustomModels",
    "GetCustomModelsByUserIDCustomModelsTypedDict",
    "GetCustomModelsByUserIDRequest",
    "GetCustomModelsByUserIDRequestTypedDict",
    "GetCustomModelsByUserIDResponse",
    "GetCustomModelsByUserIDResponseBody",
    "GetCustomModelsByUserIDResponseBodyTypedDict",
    "GetCustomModelsByUserIDResponseTypedDict",
    "GetDatasetByIDDatasets",
    "GetDatasetByIDDatasetsTypedDict",
    "GetDatasetByIDRequest",
    "GetDatasetByIDRequestTypedDict",
    "GetDatasetByIDResponse",
    "GetDatasetByIDResponseBody",
    "GetDatasetByIDResponseBodyTypedDict",
    "GetDatasetByIDResponseTypedDict",
    "GetElementByIDRequest",
    "GetElementByIDRequestTypedDict",
    "GetElementByIDResponse",
    "GetElementByIDResponseBody",
    "GetElementByIDResponseBodyTypedDict",
    "GetElementByIDResponseTypedDict",
    "GetElementByIDUserLoras",
    "GetElementByIDUserLorasTypedDict",
    "GetGenerationByIDGeneratedImageVariationGeneric",
    "GetGenerationByIDGeneratedImageVariationGenericTypedDict",
    "GetGenerationByIDGenerations",
    "GetGenerationByIDGenerationsTypedDict",
    "GetGenerationByIDLoras",
    "GetGenerationByIDLorasTypedDict",
    "GetGenerationByIDRequest",
    "GetGenerationByIDRequestTypedDict",
    "GetGenerationByIDResponse",
    "GetGenerationByIDResponseBody",
    "GetGenerationByIDResponseBodyTypedDict",
    "GetGenerationByIDResponseTypedDict",
    "GetGenerationsByUserIDGeneratedImageVariationGeneric",
    "GetGenerationsByUserIDGeneratedImageVariationGenericTypedDict",
    "GetGenerationsByUserIDGeneratedImages",
    "GetGenerationsByUserIDGeneratedImagesTypedDict",
    "GetGenerationsByUserIDGenerationElements",
    "GetGenerationsByUserIDGenerationElementsTypedDict",
    "GetGenerationsByUserIDGenerations",
    "GetGenerationsByUserIDGenerationsTypedDict",
    "GetGenerationsByUserIDRequest",
    "GetGenerationsByUserIDRequestTypedDict",
    "GetGenerationsByUserIDResponse",
    "GetGenerationsByUserIDResponseBody",
    "GetGenerationsByUserIDResponseBodyTypedDict",
    "GetGenerationsByUserIDResponseTypedDict",
    "GetInitImageByIDInitImages",
    "GetInitImageByIDInitImagesTypedDict",
    "GetInitImageByIDRequest",
    "GetInitImageByIDRequestTypedDict",
    "GetInitImageByIDResponse",
    "GetInitImageByIDResponseBody",
    "GetInitImageByIDResponseBodyTypedDict",
    "GetInitImageByIDResponseTypedDict",
    "GetModelByIDCustomModels",
    "GetModelByIDCustomModelsTypedDict",
    "GetModelByIDRequest",
    "GetModelByIDRequestTypedDict",
    "GetModelByIDResponse",
    "GetModelByIDResponseBody",
    "GetModelByIDResponseBodyTypedDict",
    "GetModelByIDResponseTypedDict",
    "GetTextureGenerationByIDModelAssetTextureGenerations",
    "GetTextureGenerationByIDModelAssetTextureGenerationsTypedDict",
    "GetTextureGenerationByIDRequest",
    "GetTextureGenerationByIDRequestBody",
    "GetTextureGenerationByIDRequestBodyTypedDict",
    "GetTextureGenerationByIDRequestTypedDict",
    "GetTextureGenerationByIDResponse",
    "GetTextureGenerationByIDResponseBody",
    "GetTextureGenerationByIDResponseBodyTypedDict",
    "GetTextureGenerationByIDResponseTypedDict",
    "GetTextureGenerationsByModelIDModelAssetTextureGenerations",
    "GetTextureGenerationsByModelIDModelAssetTextureGenerationsTypedDict",
    "GetTextureGenerationsByModelIDModelAssetTextureImages",
    "GetTextureGenerationsByModelIDModelAssetTextureImagesTypedDict",
    "GetTextureGenerationsByModelIDRequest",
    "GetTextureGenerationsByModelIDRequestBody",
    "GetTextureGenerationsByModelIDRequestBodyTypedDict",
    "GetTextureGenerationsByModelIDRequestTypedDict",
    "GetTextureGenerationsByModelIDResponse",
    "GetTextureGenerationsByModelIDResponseBody",
    "GetTextureGenerationsByModelIDResponseBodyTypedDict",
    "GetTextureGenerationsByModelIDResponseTypedDict",
    "GetUserSelfResponse",
    "GetUserSelfResponseBody",
    "GetUserSelfResponseBodyTypedDict",
    "GetUserSelfResponseTypedDict",
    "GetVariationByIDRequest",
    "GetVariationByIDRequestTypedDict",
    "GetVariationByIDResponse",
    "GetVariationByIDResponseBody",
    "GetVariationByIDResponseBodyTypedDict",
    "GetVariationByIDResponseTypedDict",
    "InitImageUploadOutput",
    "InitImageUploadOutputTypedDict",
    "InitImages",
    "InitImagesTypedDict",
    "LcmGenerationOutput",
    "LcmGenerationOutputTypedDict",
    "ListElementsResponse",
    "ListElementsResponseBody",
    "ListElementsResponseBodyTypedDict",
    "ListElementsResponseTypedDict",
    "ListPlatformModelsCustomModels",
    "ListPlatformModelsCustomModelsTypedDict",
    "ListPlatformModelsGeneratedImages",
    "ListPlatformModelsGeneratedImagesTypedDict",
    "ListPlatformModelsResponse",
    "ListPlatformModelsResponseBody",
    "ListPlatformModelsResponseBodyTypedDict",
    "ListPlatformModelsResponseTypedDict",
    "Loras",
    "LorasTypedDict",
    "ModelAssetTextureGenerations",
    "ModelAssetTextureGenerationsTypedDict",
    "ModelAssetTextureImages",
    "ModelAssetTextureImagesTypedDict",
    "ModelAssetUploadOutput",
    "ModelAssetUploadOutputTypedDict",
    "ModelAssets",
    "ModelAssetsTypedDict",
    "MotionSvdGenerationOutput",
    "MotionSvdGenerationOutputTypedDict",
    "Object",
    "ObjectTypedDict",
    "PerformAlchemyUpscaleLCMLCMGenerationOutput",
    "PerformAlchemyUpscaleLCMLCMGenerationOutputTypedDict",
    "PerformAlchemyUpscaleLCMRequestBody",
    "PerformAlchemyUpscaleLCMRequestBodyTypedDict",
    "PerformAlchemyUpscaleLCMResponse",
    "PerformAlchemyUpscaleLCMResponseBody",
    "PerformAlchemyUpscaleLCMResponseBodyTypedDict",
    "PerformAlchemyUpscaleLCMResponseTypedDict",
    "PerformInpaintingLCMLCMGenerationOutput",
    "PerformInpaintingLCMLCMGenerationOutputTypedDict",
    "PerformInpaintingLCMRequestBody",
    "PerformInpaintingLCMRequestBodyTypedDict",
    "PerformInpaintingLCMResponse",
    "PerformInpaintingLCMResponseBody",
    "PerformInpaintingLCMResponseBodyTypedDict",
    "PerformInpaintingLCMResponseTypedDict",
    "PerformInstantRefineLcmGenerationOutput",
    "PerformInstantRefineLcmGenerationOutputTypedDict",
    "PerformInstantRefineRequestBody",
    "PerformInstantRefineRequestBodyTypedDict",
    "PerformInstantRefineResponse",
    "PerformInstantRefineResponseBody",
    "PerformInstantRefineResponseBodyTypedDict",
    "PerformInstantRefineResponseTypedDict",
    "PricingCalculatorObject",
    "PricingCalculatorObjectTypedDict",
    "PricingCalculatorPricingCalculatorObject",
    "PricingCalculatorPricingCalculatorObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestObject",
    "PricingCalculatorPricingCalculatorRequestObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsTEXTUREGENERATIONObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERObjectTypedDict",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObject",
    "PricingCalculatorPricingCalculatorRequestRequestBodyServiceParamsUNIVERSALUPSCALERULTRAObjectTypedDict",
    "PricingCalculatorRequestBody",
    "PricingCalculatorRequestBodyTypedDict",
    "PricingCalculatorResponse",
    "PricingCalculatorResponseBody",
    "PricingCalculatorResponseBodyTypedDict",
    "PricingCalculatorResponseTypedDict",
    "PromptGenerationOutput",
    "PromptGenerationOutputTypedDict",
    "PromptImproveRequestBody",
    "PromptImproveRequestBodyTypedDict",
    "PromptImproveResponse",
    "PromptImproveResponseBody",
    "PromptImproveResponseBodyTypedDict",
    "PromptImproveResponseTypedDict",
    "PromptRandomPromptGenerationOutput",
    "PromptRandomPromptGenerationOutputTypedDict",
    "PromptRandomResponse",
    "PromptRandomResponseBody",
    "PromptRandomResponseBodyTypedDict",
    "PromptRandomResponseTypedDict",
    "SDGenerationOutput",
    "SDGenerationOutputTypedDict",
    "SDTrainingOutput",
    "SDTrainingOutputTypedDict",
    "SDUnzoomOutput",
    "SDUnzoomOutputTypedDict",
    "SDUpscaleJobOutput",
    "SDUpscaleJobOutputTypedDict",
    "SdVersions",
    "TextureGenerationJobOutput",
    "TextureGenerationJobOutputTypedDict",
    "TransparencyType",
    "UniversalUpscalerOutput",
    "UniversalUpscalerOutputTypedDict",
    "UploadCanvasInitImageRequestBody",
    "UploadCanvasInitImageRequestBodyTypedDict",
    "UploadCanvasInitImageResponse",
    "UploadCanvasInitImageResponseBody",
    "UploadCanvasInitImageResponseBodyTypedDict",
    "UploadCanvasInitImageResponseTypedDict",
    "UploadDatasetImageFromGenRequest",
    "UploadDatasetImageFromGenRequestBody",
    "UploadDatasetImageFromGenRequestBodyTypedDict",
    "UploadDatasetImageFromGenRequestTypedDict",
    "UploadDatasetImageFromGenResponse",
    "UploadDatasetImageFromGenResponseBody",
    "UploadDatasetImageFromGenResponseBodyTypedDict",
    "UploadDatasetImageFromGenResponseTypedDict",
    "UploadDatasetImageRequest",
    "UploadDatasetImageRequestBody",
    "UploadDatasetImageRequestBodyTypedDict",
    "UploadDatasetImageRequestTypedDict",
    "UploadDatasetImageResponse",
    "UploadDatasetImageResponseBody",
    "UploadDatasetImageResponseBodyTypedDict",
    "UploadDatasetImageResponseTypedDict",
    "UploadInitImageRequestBody",
    "UploadInitImageRequestBodyTypedDict",
    "UploadInitImageResponse",
    "UploadInitImageResponseBody",
    "UploadInitImageResponseBodyTypedDict",
    "UploadInitImageResponseTypedDict",
    "UploadModelAssetRequestBody",
    "UploadModelAssetRequestBodyTypedDict",
    "UploadModelAssetResponse",
    "UploadModelAssetResponseBody",
    "UploadModelAssetResponseBodyTypedDict",
    "UploadModelAssetResponseTypedDict",
    "UserDetails",
    "UserDetailsTypedDict",
    "UserLoras",
    "UserLorasTypedDict",
    "Users",
    "UsersTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.models.shared import (
    job_status as shared_job_status,
    model_asset_texture_types as shared_model_asset_texture_types,
)
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from leonardo_ai_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetTextureGenerationByIDRequestBodyTypedDict(TypedDict):
    r"""Query parameters can also be provided in the request body as a JSON object"""

    id: NotRequired[Nullable[str]]


class GetTextureGenerationByIDRequestBody(BaseModel):
    r"""Query parameters can also be provided in the request body as a JSON object"""

    id: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id"]
        nullable_fields = ["id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetTextureGenerationByIDRequestTypedDict(TypedDict):
    id: str
    r"""_\"id\" is required (enter it either in parameters or request body)_"""
    request_body: NotRequired[GetTextureGenerationByIDRequestBodyTypedDict]
    r"""Query parameters can also be provided in the request body as a JSON object"""
    limit: NotRequired[int]
    offset: NotRequired[int]


class GetTextureGenerationByIDRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""_\"id\" is required (enter it either in parameters or request body)_"""

    request_body: Annotated[
        Optional[GetTextureGenerationByIDRequestBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None
    r"""Query parameters can also be provided in the request body as a JSON object"""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 10

    offset: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0


class ModelAssetTextureImagesTypedDict(TypedDict):
    r"""columns and relationships of \"model_asset_texture_images\" """

    id: NotRequired[Nullable[str]]
    type: NotRequired[shared_model_asset_texture_types.ModelAssetTextureTypes]
    r"""When training model assets these are the texture types available to use."""
    url: NotRequired[str]


class ModelAssetTextureImages(BaseModel):
    r"""columns and relationships of \"model_asset_texture_images\" """

    id: OptionalNullable[str] = UNSET

    type: Optional[shared_model_asset_texture_types.ModelAssetTextureTypes] = (
        shared_model_asset_texture_types.ModelAssetTextureTypes.NORMAL
    )
    r"""When training model assets these are the texture types available to use."""

    url: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "type", "url"]
        nullable_fields = ["id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetTextureGenerationByIDModelAssetTextureGenerationsTypedDict(TypedDict):
    r"""columns and relationships of \"model_asset_texture_generations\" """

    created_at: NotRequired[str]
    id: NotRequired[Nullable[str]]
    model_asset_texture_images: NotRequired[List[ModelAssetTextureImagesTypedDict]]
    negative_prompt: NotRequired[Nullable[str]]
    prompt: NotRequired[str]
    seed: NotRequired[Nullable[int]]
    status: NotRequired[shared_job_status.JobStatus]
    r"""The status of the current task."""


class GetTextureGenerationByIDModelAssetTextureGenerations(BaseModel):
    r"""columns and relationships of \"model_asset_texture_generations\" """

    created_at: Annotated[Optional[str], pydantic.Field(alias="createdAt")] = None

    id: OptionalNullable[str] = UNSET

    model_asset_texture_images: Optional[List[ModelAssetTextureImages]] = None

    negative_prompt: Annotated[
        OptionalNullable[str], pydantic.Field(alias="negativePrompt")
    ] = UNSET

    prompt: Optional[str] = None

    seed: OptionalNullable[int] = UNSET

    status: Optional[shared_job_status.JobStatus] = None
    r"""The status of the current task."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "createdAt",
            "id",
            "model_asset_texture_images",
            "negativePrompt",
            "prompt",
            "seed",
            "status",
        ]
        nullable_fields = ["id", "negativePrompt", "seed"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetTextureGenerationByIDResponseBodyTypedDict(TypedDict):
    r"""Responses for GET /api/rest/v1/generations-texture/{id}"""

    model_asset_texture_generations_by_pk: NotRequired[
        Nullable[GetTextureGenerationByIDModelAssetTextureGenerationsTypedDict]
    ]
    r"""columns and relationships of \"model_asset_texture_generations\" """


class GetTextureGenerationByIDResponseBody(BaseModel):
    r"""Responses for GET /api/rest/v1/generations-texture/{id}"""

    model_asset_texture_generations_by_pk: OptionalNullable[
        GetTextureGenerationByIDModelAssetTextureGenerations
    ] = UNSET
    r"""columns and relationships of \"model_asset_texture_generations\" """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["model_asset_texture_generations_by_pk"]
        nullable_fields = ["model_asset_texture_generations_by_pk"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetTextureGenerationByIDResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[GetTextureGenerationByIDResponseBodyTypedDict]
    r"""Responses for GET /api/rest/v1/generations-texture/{id}"""


class GetTextureGenerationByIDResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[GetTextureGenerationByIDResponseBody] = None
    r"""Responses for GET /api/rest/v1/generations-texture/{id}"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from leonardo_ai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateSVDMotionGenerationRequestBodyTypedDict(TypedDict):
    r"""Query parameters can also be provided in the request body as a JSON object"""

    image_id: str
    r"""The ID of the image, supports generated images, variation images, and init images."""
    is_init_image: NotRequired[Nullable[bool]]
    r"""If it is an init image uploaded by the user. This image is uploaded from endpoint: Upload init image."""
    is_public: NotRequired[Nullable[bool]]
    r"""Whether the generation is public or not"""
    is_variation: NotRequired[Nullable[bool]]
    r"""If it is a variation image."""
    motion_strength: NotRequired[Nullable[int]]
    r"""The motion strength."""


class CreateSVDMotionGenerationRequestBody(BaseModel):
    r"""Query parameters can also be provided in the request body as a JSON object"""

    image_id: Annotated[str, pydantic.Field(alias="imageId")]
    r"""The ID of the image, supports generated images, variation images, and init images."""

    is_init_image: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="isInitImage")
    ] = UNSET
    r"""If it is an init image uploaded by the user. This image is uploaded from endpoint: Upload init image."""

    is_public: Annotated[OptionalNullable[bool], pydantic.Field(alias="isPublic")] = (
        UNSET
    )
    r"""Whether the generation is public or not"""

    is_variation: Annotated[
        OptionalNullable[bool], pydantic.Field(alias="isVariation")
    ] = UNSET
    r"""If it is a variation image."""

    motion_strength: Annotated[
        OptionalNullable[int], pydantic.Field(alias="motionStrength")
    ] = UNSET
    r"""The motion strength."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["isInitImage", "isPublic", "isVariation", "motionStrength"]
        nullable_fields = ["isInitImage", "isPublic", "isVariation", "motionStrength"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class MotionSvdGenerationOutputTypedDict(TypedDict):
    api_credit_cost: NotRequired[Nullable[int]]
    r"""API credits cost, available for Production API users."""
    generation_id: NotRequired[str]


class MotionSvdGenerationOutput(BaseModel):
    api_credit_cost: Annotated[
        OptionalNullable[int], pydantic.Field(alias="apiCreditCost")
    ] = UNSET
    r"""API credits cost, available for Production API users."""

    generation_id: Annotated[Optional[str], pydantic.Field(alias="generationId")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["apiCreditCost", "generationId"]
        nullable_fields = ["apiCreditCost"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateSVDMotionGenerationResponseBodyTypedDict(TypedDict):
    r"""Responses for POST /generations-motion-svd"""

    sd_generation_job: NotRequired[Nullable[MotionSvdGenerationOutputTypedDict]]


class CreateSVDMotionGenerationResponseBody(BaseModel):
    r"""Responses for POST /generations-motion-svd"""

    sd_generation_job: Annotated[
        OptionalNullable[MotionSvdGenerationOutput],
        pydantic.Field(alias="sdGenerationJob"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["sdGenerationJob"]
        nullable_fields = ["sdGenerationJob"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateSVDMotionGenerationResponseTypedDict(TypedDict):
    content_type: str
    r"""HTTP response content type for this operation"""
    status_code: int
    r"""HTTP response status code for this operation"""
    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""
    object: NotRequired[CreateSVDMotionGenerationResponseBodyTypedDict]
    r"""Responses for POST /generations-motion-svd"""


class CreateSVDMotionGenerationResponse(BaseModel):
    content_type: str
    r"""HTTP response content type for this operation"""

    status_code: int
    r"""HTTP response status code for this operation"""

    raw_response: httpx.Response
    r"""Raw HTTP response; suitable for custom response parsing"""

    object: Optional[CreateSVDMotionGenerationResponseBody] = None
    r"""Responses for POST /generations-motion-svd"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from typing_extensions import deprecated


@deprecated(
    "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
)
class ControlnetType(str, Enum):
    r"""This parameter will be deprecated in September 2024. Please use the controlnets array instead."""

    POSE = "POSE"
    CANNY = "CANNY"
    DEPTH = "DEPTH"
